package category

import (
	"context"
	"fmt"

	"github.com/jackc/pgx/v5"
	"github.com/jackc/pgx/v5/pgxpool"
)

type CategoryEntity struct {
	Id           int
	Name         string
	BudgetId     int
	Favorite     bool
	MonthlyLimit int
}

type CategoryService struct {
	db *pgxpool.Pool
}

func NewCategoryService(
	db *pgxpool.Pool,
) *CategoryService {
	return &CategoryService{
		db: db,
	}
}

func (s *CategoryService) AddCategory(ctx context.Context, category *CategoryEntity) (*CategoryEntity, error) {
	query := `INSERT INTO categories (name, budget_id, favorite, monthly_limit) VALUES (@name, @budget_id, @favorite, @monthly_limit) RETURNING id`
	args := pgx.NamedArgs{
		"name":          category.Name,
		"budget_id":     category.BudgetId,
		"favorite":      category.Favorite,
		"monthly_limit": category.MonthlyLimit,
	}
	if err := s.db.QueryRow(ctx, query, args).Scan(&category.Id); err != nil {
		return nil, fmt.Errorf("unable to insert row: %w", err)
	}
	return category, nil
}
